@@ -34,7 +34,7 @@ def quickname(station,year,cyy, cdoy, csnr):
     fname =  xdir + str(year) + '/snr/' + station + '/' + station + cdoy + '0.' + cyy + '.snr' + csnr
     return fname
 
-def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate):
+def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,archive,fortran,nol,overwrite,translator,srate,mk,skipit):
     """
     runs the rinex 2 snr conversion
     inputs:
@@ -49,37 +49,67 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
     fortran = boolean, whether you use fortran rinex translators
     nol = boolean for nolook, if set to True, then it will assume RINEX files are in local directory
     overwrite = boolean, make a new SNR file even if one already exists
+    translate = string with .... fortran, python, hybrid ??
+    srate = sample rate
+    mk = makan option
+    skipit = skips making files every day, so a value of 7 means weekly.  1 means do every day
 
     2021feb11, kristine Larson
     translator = fortran, python, or hybrid
     srate - integer sample rate, for RINEX 3 only.
     2021mar20 check for illegal day of years ....
+    2021aug01 added mk option for uppercase file names per makan karegar request
+    2021aug15v added weekly option
     """
+    # do not allow illegal skipit values
+    if skipit < 1:
+        skipit = 1
 
     NS = len(station)
     if (NS == 4):
         #print('Assume RINEX 2.11'); 
         version = 2
-        station = station.lower()
+        if not mk:
+            station = station.lower()
     elif (NS == 9):
         #print('Assume RINEX 3'); 
         version = 3
         station9ch = station.upper()
-        station = station[0:4].lower()
+        if not mk:
+            station = station[0:4].lower()
     else:
         print('Illegal station input - Station must have 4 or 9 characters. Exiting')
         sys.exit()
+    year_st = year_list[0]
+    year_end = year_list[-1]
+    doy_st = doy_list[0]
+    doy_end = doy_list[-1]
+    # 2021 september 12 KL
+    # i would like to put this in rinex2snr_cl.py - but I am trying to avoid increasing
+    # the workload for the Notebook programmers before the short course.
+    #print(year_st,year_end,doy_st, doy_end)
 
+# this way we are overwriting the doy_list variable
 # loop thru years and days 
     for year in year_list:
         ann = g.make_nav_dirs(year)
+        cyyyy = str(year)
         dec31 = g.dec31(year)
+        if year != year_end:
+            doy_en = dec31
+        else:
+            doy_en = doy_end
+
+        if year == year_st:
+            doy_list = list(range(doy_st, doy_en+1,skipit))
+        else:
+            doy_list = list(range(1, doy_en+1,skipit))
+
         for doy in doy_list:
             csnr = str(isnr)
             cdoy = '{:03d}'.format(doy) ; cyy = '{:02d}'.format(year-2000)
             # first, check to see if the SNR file exists
             fname =  quickname(station,year,cyy,cdoy,csnr)
-            #print(fname)
             snre = g.snr_exist(station,year,doy,csnr)
             if snre:
                 print('SNR file exists', fname)
@@ -95,14 +125,13 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
             if (not illegal_day) and (not snre):
                 r = station + cdoy + '0.' + cyy + 'o'
                 rgz = station + cdoy + '0.' + cyy + 'o.gz'
-                print('Will seek RINEX file ', station, ' year:', year, ' doy:', doy, ' translate with ', translator)
+                print('Will seek RINEX file ', station, ' year:', year, ' doy:', doy, ' translate with ', translator, ' at the ', archive, ' archive')
                 if nol:
-                    # this assumes RINEX file is in local directory
+                    # this assumes RINEX file is in local directory or "nearby"
                     if version == 2:
-                        if os.path.exists(r) or os.path.exists(rgz):
+                        the_makan_option(station,cyyyy,cyy,cdoy) # looks everywhere in your local directories
+                        if os.path.exists(r):
                             #print('RINEX 2 file exists locally')
-                            if not os.path.exists(r):
-                                subprocess.call(['gunzip', rgz])
                             conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
                         else:
                             print('You Chose the No Look Option, but did not provide the needed RINEX file.')
@@ -126,23 +155,28 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                             print('You Chose the No Look Option, but did not provide the needed RINEX3 file.')
 
                 else:
-                    #print('will look for the RINEX file both locally and externally')
                     if version == 3:
                         #  try unavco
-                        if (archive == 'all') or (archive == 'unavco'):
+                        rinex2exists = False; rinex3name = '';
+                        if (archive == 'unavco') or (archive == 'all'):
                             srate = 15
                             rinex2exists, rinex3name = g.unavco_rinex3(station9ch, year, doy,srate,orbtype)
 
                         # try cddis
                         if not os.path.exists(r):
-                            if (archive == 'all') or (archive == 'cddis'):
+                            if (archive == 'cddis') or (archive == 'all'):
                                 srate = 30
                                 rinex2exists, rinex3name = g.cddis_rinex3(station9ch, year, doy,srate,orbtype)
+                        if not os.path.exists(r):
+                            if (archive == 'ga') :
+                                srate = 30
+                                rinex2exists, rinex3name = g.ga_rinex3_to_rinex2(station9ch, year, doy,srate)
 
                         # remove rinex 3 file
-                        subprocess.call(['rm', '-f', rinex3name]) # remove rinex3 file
+                        # subprocess.call(['rm', '-f', rinex3name]) # remove rinex3 file
 
                         if rinex2exists:
+                            print('RINEX version 2 has been created from version 3', year, doy)
                             conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator) 
                         else:
                             print('RINEX file does not exist for ', year, doy)
@@ -190,6 +224,7 @@ def conv2snr(year, doy, station, option, orbtype,receiverrate,dec_rate,archive,f
         # new function to do the whole orbit thing
         foundit, f, orbdir, snrexe = g.get_orbits_setexe(year,month,day,orbtype,fortran) 
         # if you have the orbit file, you can get the rinex file
+        print('Orbit file: ', orbdir + '/' + f)
         if foundit:
             # now you can look for a rinex file
             rinexfile,rinexfiled = g.rinex_name(station, year, month, day)
@@ -791,3 +826,107 @@ def testing_sp3(gpstime,sp3,systemsatlists,obsdata,obstypes,prntoidx,year,month,
                 # store it in the original rinex filename
                     #subprocess.call(['rm','-f',rinexfile])
                     #subprocess.call(['mv','-f',foutname, rinexfile])
+
+def the_makan_option(station,cyyyy,cyy,cdoy):
+    """
+    this ugly looking code checks a bazillion versions of RINEX versions
+    (Z, gz, regular, hatanaka) both in the working directory and in an external rinex area
+    $REFL_CODE/rinex/station/year
+    
+    turns whatever it finds into a regular RINEX file in the working directory
+    that file WILL be deleted, but it will not delete those stored externally.
+    """
+    missing = True
+    crnxpath = g.hatanaka_version()  # where hatanaka will be
+    r = station + cdoy + '0.' + cyy + 'o'
+    rd = station + cdoy + '0.' + cyy + 'd'
+    locdir= os.environ['REFL_CODE'] + '/rinex/' + station + '/' + cyyyy + '/'
+    # 
+    #locdir2= os.environ['RINEX'] + station + '/' + cyyyy + '/'
+    #locdir3= os.environ['RINEX'] + station.upper() + '/' + cyyyy + '/'
+
+    print('Will look for files in the working directory and ', locdir)
+    # I was testing this ... but have not finished
+    #so_many_permutations(r,rd,locdir, crnxpath)
+
+    if os.path.exists(r):
+        missing = False
+
+    if os.path.exists(r + '.gz') and missing:
+        subprocess.call(['gunzip', r + '.gz'])
+        missing = False
+
+    if os.path.exists(r + '.Z') and missing:
+        subprocess.call(['uncompress', r + '.Z'])
+        missing = False
+
+    if os.path.exists(rd) and missing:
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            subprocess.call(['rm',rd])
+            missing = False
+        else:
+            g.hatanaka_warning(); return
+
+    if os.path.exists(rd + '.gz') and missing:
+        subprocess.call(['gunzip', rd + '.gz'])
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            subprocess.call(['rm',rd])
+            missing = False
+        else:
+            g.hatanaka_warning(); 
+
+    if os.path.exists(rd + '.Z') and missing:
+        subprocess.call(['uncompress', rd + '.Z'])
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            subprocess.call(['rm',rd])
+            missing = False
+        else:
+            g.hatanaka_warning() 
+
+    if os.path.exists(locdir + r) and missing:
+        subprocess.call(['cp', '-f',locdir + r,'.'])
+        missing = False
+
+    if os.path.exists(locdir + r + '.gz') and missing:
+        subprocess.call(['cp', '-f',locdir + r + '.gz' ,'.'])
+        subprocess.call(['gunzip', r + '.gz'])
+        missing = False
+
+    if os.path.exists(locdir + r + '.Z') and missing:
+        subprocess.call(['cp', '-f',locdir + r + '.Z','.'])
+        subprocess.call(['uncompress', r + '.Z'])
+        missing = False
+
+    if os.path.exists(locdir + rd) and missing:
+        subprocess.call(['cp','-f',locdir + rd,'.'])
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            subprocess.call(['rm',rd])
+            missing = False
+        else:
+            g.hatanaka_warning(); 
+
+    if os.path.exists(locdir + rd + '.Z') and missing:
+        subprocess.call(['cp','-f',locdir + rd + '.Z','.'])
+        subprocess.call(['uncompress', rd + '.Z'])
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            subprocess.call(['rm',rd])
+            missing = False
+        else:
+            g.hatanaka_warning(); 
+
+    if os.path.exists(locdir + rd + '.gz') and missing:
+        subprocess.call(['cp','-f',locdir + rd + '.gz','.'])
+        subprocess.call(['gunzip',rd + '.gz'])
+        if os.path.exists(crnxpath):
+            subprocess.call([crnxpath,rd])
+            subprocess.call(['rm',rd])
+            missing = False
+        else:
+            g.hatanaka_warning()
+
+
